@@ -1,7 +1,7 @@
 `aDist` <-
   function(x, y){
       if(is.vector(x)) x <- matrix(x, ncol=length(x))
-	  if(is.vector(y)) x <- matrix(y, ncol=length(y))	  
+	  if(is.vector(y)) y <- matrix(y, ncol=length(y))	  
 	  
 	  matOrig <- as.numeric(t(x))
 	  matImp <- as.numeric(t(y))
